Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(776)

Unified Diff: ui/views/animation/flood_fill_ink_drop_animation.h

Issue 1942843002: Fixed material design ink drop location for the MD download shelf buttons. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2704
Patch Set: Added some missing includes. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/animation/flood_fill_ink_drop_animation.h
diff --git a/ui/views/animation/flood_fill_ink_drop_animation.h b/ui/views/animation/flood_fill_ink_drop_animation.h
index 2449895ce343e590f965bd243bcc27cf40963fd6..2ddde9647afe38f2c6d631eb4db17a368e34394c 100644
--- a/ui/views/animation/flood_fill_ink_drop_animation.h
+++ b/ui/views/animation/flood_fill_ink_drop_animation.h
@@ -15,6 +15,7 @@
#include "ui/compositor/layer_animator.h"
#include "ui/gfx/animation/tween.h"
#include "ui/gfx/geometry/point.h"
+#include "ui/gfx/geometry/rect.h"
#include "ui/gfx/geometry/size.h"
#include "ui/gfx/transform.h"
#include "ui/views/animation/ink_drop_animation.h"
@@ -48,7 +49,7 @@ class FloodFillInkDropAnimationTestApi;
//
class VIEWS_EXPORT FloodFillInkDropAnimation : public InkDropAnimation {
public:
- FloodFillInkDropAnimation(const gfx::Size& size,
+ FloodFillInkDropAnimation(const gfx::Rect& clip_bounds,
const gfx::Point& center_point,
SkColor color);
~FloodFillInkDropAnimation() override;
@@ -101,8 +102,8 @@ class VIEWS_EXPORT FloodFillInkDropAnimation : public InkDropAnimation {
// Returns the target Transform for when the ink drop is fully shown.
gfx::Transform GetMaxSizeTargetTransform() const;
- // The clip Size.
- const gfx::Size size_;
+ // The clip bounds.
+ const gfx::Rect clip_bounds_;
// The point where the Center of the ink drop's circle should be drawn.
gfx::Point center_point_;
« no previous file with comments | « chrome/browser/ui/views/download/download_item_view_md.cc ('k') | ui/views/animation/flood_fill_ink_drop_animation.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698